@@ -6,10 +6,10 @@
 
 #pragma once
 
+#include <Akonadi/Collection>
+#include <KCalendarCore/Calendar>
 #include <QObject>
 #include <QString>
-#include <collection.h>
-#include <kcalendarcore/calendar.h>
 
 namespace Akonadi
 {
