@@ -13,15 +13,15 @@
 #include "etmcalendar_p.h"
 #include "kcolumnfilterproxymodel_p.h"
 #include "utils_p.h"
+#include <Akonadi/CollectionFilterProxyModel>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/Item>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
+#include <Akonadi/Session>
 #include <KDescendantsProxyModel>
 #include <KSelectionProxyModel>
-#include <collectionfilterproxymodel.h>
-#include <entitydisplayattribute.h>
-#include <entitymimetypefiltermodel.h>
-#include <item.h>
-#include <itemfetchscope.h>
-#include <monitor.h>
-#include <session.h>
 
 #include <QItemSelectionModel>
 #include <QTreeView>
@@ -46,7 +46,7 @@ void ETMCalendarPrivate::init()
         auto monitor = new Akonadi::Monitor(q);
         monitor->setObjectName(QStringLiteral("ETMCalendarMonitor"));
         connect(monitor,
-                QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Monitor::collectionChanged),
+                qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Monitor::collectionChanged),
                 this,
                 [this](const Akonadi::Collection &cols, const QSet<QByteArray> &set) {
                     onCollectionChanged(cols, set);
@@ -252,7 +252,7 @@ Akonadi::Collection::List ETMCalendarPrivate::collectionsFromModel(const QAbstra
 
 Akonadi::Item ETMCalendarPrivate::itemFromIndex(const QModelIndex &idx)
 {
-    Akonadi::Item item = idx.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    auto item = idx.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     item.setParentCollection(idx.data(Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>());
     return item;
 }
@@ -454,7 +454,7 @@ ETMCalendar::ETMCalendar(Monitor *monitor, QObject *parent)
 
     if (monitor) {
         QObject::connect(monitor,
-                         QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Akonadi::Monitor::collectionChanged),
+                         qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Akonadi::Monitor::collectionChanged),
                          d,
                          &ETMCalendarPrivate::onCollectionChanged);
         d->mETM = CalendarModel::create(monitor);
@@ -606,7 +606,7 @@ bool ETMCalendar::isLoaded() const
         return false;
     }
 
-    for (const Akonadi::Collection &collection : qAsConst(d->mCollectionMap)) {
+    for (const Akonadi::Collection &collection : std::as_const(d->mCollectionMap)) {
         if (!entityTreeModel()->isCollectionPopulated(collection.id())) {
             return false;
         }
