@@ -8,8 +8,8 @@
 
 #include "history.h"
 #include "incidencechanger.h"
+#include <Akonadi/Collection>
 #include <KCalendarCore/Incidence>
-#include <collection.h>
 
 #include <QPointer>
 #include <QStack>
@@ -55,12 +55,12 @@ private:
     Q_DISABLE_COPY(Entry)
 };
 
-class AKONADI_CALENDAR_EXPORT History::Private : public QObject
+class AKONADI_CALENDAR_EXPORT HistoryPrivate : public QObject
 {
     Q_OBJECT
 public:
-    Private(History *qq);
-    ~Private()
+    explicit HistoryPrivate(History *qq);
+    ~HistoryPrivate() override
     {
     }
 
@@ -89,14 +89,14 @@ public:
     Entry::Ptr mEntryInProgress;
 
     QString mLastErrorString;
-    bool mUndoAllInProgress;
+    bool mUndoAllInProgress = false;
 
     /**
      * When recordCreation/Deletion/Modification is called and an undo operation is already in progress
      * the entry is added here.
      */
     QVector<Entry::Ptr> mQueuedEntries;
-    bool mEnabled;
+    bool mEnabled = true;
     QPointer<QWidget> mCurrentParent;
 
 public Q_SLOTS:
