@@ -6,13 +6,13 @@
 */
 
 #include "incidencefetchjob_p.h"
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
-#include <collectionfetchjob.h>
-#include <collectionfetchscope.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
-#include <kcalendarcore/todo.h>
+#include <KCalendarCore/Todo>
 
 using namespace Akonadi;
 
