@@ -9,11 +9,15 @@
 #include "mailclient_p.h"
 #include "scheduler_p.h"
 
+#include <Akonadi/Item>
 #include <KCalendarCore/Incidence>
-#include <item.h>
+
+#include <memory>
 
 namespace Akonadi
 {
+class MailSchedulerPrivate;
+
 /*
   This class implements the iTIP interface using the email interface specified
   as Mail.
@@ -56,8 +60,7 @@ private:
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(MailScheduler)
-    class Private;
-    Private *const d;
+    std::unique_ptr<MailSchedulerPrivate> const d;
     //@endcond
 };
 }
